/*==================================================================
 Program: Main_e2014.do
 Purpose: Main data analysis for the 2014 RCT.
==================================================================*/

clear
set more off

/*==================================================================
COVARIATE BALANCE AND BACKGROUND STATS
==================================================================*/

/*================================================
Appendix Table C14: Sample Means
================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
matrix input M = (1,2,3,4,5,6,7,8,9)
matrix input N = (1\2\3\4\5\6\7\8\9\10\11)
matrix H=N*M
matrix rownames H = Male Black Hispanic Other_race Age Democrat Republican Other_party vote2008? vote2010? vote2012?
matrix colnames H = control close+big close+small notclose+big  notclose+small close notclose big small
matrix list H

foreach yX in t_close t_fewvoters{
	assert `yX'==0 | `yX'==1 | mi(`yX')
}

global CharList = "male black hisp race_other age reg_dem reg_rep reg_otherparty vote2008 vote2010 vote2012"
local Counter = 0
foreach yX of global CharList{
	local Counter = `Counter'+1
	mean `yX', over(treatment)
	matrix H[`Counter',1]=e(b)
	mean `yX', over(t_close)
	matrix J=e(b)
	matrix H[`Counter',6]=J[1,2]
	matrix H[`Counter',7]=J[1,1]
	mean `yX', over(t_fewvoters)
	matrix J=e(b)
	matrix H[`Counter',8]=J[1,2]
	matrix H[`Counter',9]=J[1,1]
}
* H1 is rounded version of H.
matrix H1 = H
forvalues iX=1/11{
	forvalues kX=1/9{
		matrix H1[`iX',`kX']=round(H[`iX',`kX'],.001)
	}
}
outtable using "$ObPath/Tab-AllTreat-Means-$spec", mat(H1) nobox replace center

* Rates of missingness discussed in notes for Table C14.
set more off
use "$Temp/2014_RCT.dta", clear
sum mi_gender 
assert r(mean)<.01
sum mi_race 
assert r(mean)<.01
sum reg_unknown
assert round(r(mean),.01)==0.42

/*================================================
Appendix Table C15: p-values.
================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
matrix input M = (1,2,3)
matrix input N = (1\2\3\4\5\6\7\8\9\10\11)
matrix H=N*M
matrix rownames H = Male Black Hispanic Other_race Age Democrat Republican Other_party vote2008? vote2010? vote2012?
matrix colnames H = close/notclose close/control control/notclose
matrix list H
global CharList = "male black hisp race_other age reg_dem reg_rep reg_otherparty vote2008 vote2010 vote2012"
local Counter = 0
foreach yX of global CharList{
	local Counter = `Counter'+1
	* Compare Close vs. Not Close. Exclude Control.
	ttest `yX', by(t_close)
		matrix H[`Counter',1]=round(r(p),.001)
	* Compare Close vs. Control. Exclude Not Close.
	ttest `yX' if t_close!=0, by(t_close_vscontrol)
		matrix H[`Counter',2]=round(r(p),.001)
	* Compare Not Close vs. Control. Exclude Close.
	ttest `yX' if t_close!=1, by(t_notclose_vscontrol)
		matrix H[`Counter',3]=round(r(p),.001)		
}
outtable using "$ObPath/Tab-Expt2014-pVals-$spec", mat(H) nobox replace center


/*================================================
Discussed in-text in Section 3: Voting rates by 
treatment group.
================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
gen t_manyvoters = 1-t_fewvoters

matrix SS_VoteRate = [0]
foreach yX in t_close_vscontrol t_notclose_vscontrol t_fewvoters t_manyvoters{
	sum vote100 if `yX'==1
		matrix SS_VoteRate = [SS_VoteRate\ round(r(mean),.1)]
}	
matrix list SS_VoteRate
scalar zz = rowsof(SS_VoteRate)
matrix SS_VoteRate = SS_VoteRate[2..zz,1]
matrix rowname SS_VoteRate = Close Not_Close Few_Voters Many_Voters
outtable using "$ObPath/Table-Expt2014-VoteRates_$spec", mat(SS_VoteRate) nobox replace center

/*================================================
TABLE C2, PANEL B: POLLS 
================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
gen closedem = poll1 if party1=="Democrat" & t_close==1
gen closerep = poll1 if party1=="Republican" & t_close==1
gen nclosedem = poll1 if party1=="Democrat" & t_close==0
gen ncloserep = poll1 if party1=="Republican" & t_close==0
gen avgrep = 100-avgdem
collapse closedem closerep nclosedem ncloserep avgdem avgrep, by(state)
foreach yX in closedem closerep nclosedem ncloserep avgdem avgrep{
	gen `yX'_perc=string(`yX')+"\%"
	drop `yX'
	rename `yX'_perc `yX'
}
dataout, save("$ObPath/Tab-2014PollList-$spec") tex replace


/*================================================
TABLE C2, PANEL C: EXPERT INFORMATION 
================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
destring to, force replace ignore(",")
matrix input M = (1,2)
matrix input N = (1\2\3\4\5\6\7)
matrix H=N*M
local Counter = 0
foreach yX in AR FL GA KS MA MI WI{
	local Counter = `Counter'+1
	mean to if state=="`yX'", over(t_fewvoters)
	matrix J=e(b)
	matrix H[`Counter',1]=J[1,2]
	matrix H[`Counter',2]=J[1,1]
}
matrix rownames H = AR FL GA KS MA MI WI
matrix colnames H = Small_Electorate Large_Electorate
outtable using "$ObPath/Tab-ExpertInfo-$spec", mat(H) nobox replace center


/*================================================
Average poll margins by treatment
================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
drop if mi(t_close)
collapse poll_margin, by(t_close)
sum poll_margin if t_close==1
sum poll_margin if t_close==0

/*================================================
Average difference in predicted electorate size 
by treatment.
================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
destring to, force replace ignore(",")
drop if mi(to)
foreach yX in min max{
	bysort state: egen `yX'_to = `yX'(to)
}
gen ratio = max_to/min_to
sum ratio




/*==================================================================
MAIN IMPACTS ON VOTER TURNOUT

~ Baseline results (TABLE 6 in main text). Use "all".
~ Table C20: Exclude people who always voted previously in data. Use "~vote_always".
~ FN 43: Exclude people who always voted or never voted. Use "vote_onlysome".
~ Table C28: Restrict to household head (person envelope addressed to). Use "hh_head".
~ Table C26: Restrict to elections that are below median size. Use "small_state".
~ Discussed in-text in Section 4A restrict to states with no senate race.
	Use "no_senate".
~ Discussed in-text in Section 4A: restrict to states where we use 
	a 50/50 close poll. Use "state_close50".	
~ Not used: Restrict to people with active voter status. Use "active".
	
One needs to loop through all the below options to produce the different tables.	
		
yX = Sample restriction or subsample
	~ foreach yX in all ~vote_always vote_onlysome hh_head small_state no_senate state_close50 active{
==================================================================*/	
set more off
qui do "$Main_P/2014/zz_globals_e2014.do"
foreach yX in all ~vote_always vote_onlysome hh_head small_state no_senate state_close50 active {
use "$Temp/2014_RCT.dta", clear
keep if `yX'==1
areg vote100 t_close $BaseVars_V2014, absorb(strata) cluster(hhid_unique)
	capture drop zz zz1
	egen zz1 = mean(vote100) if e(sample)==1 & t_close==0
	egen zz = max(zz1)	
	outreg2 t_close using "$ObPath/Table-Expt2014-`yX'-$spec", $OR2_nodec dec(2) replace addstat(Mean dv if not close poll=1, zz)	
areg vote100 t_close $FullCont_V2014, absorb(strata) cluster(hhid_unique)
	capture drop zz zz1
	egen zz1 = mean(vote100) if e(sample)==1 & t_close==0
	egen zz = max(zz1)	
	outreg2 t_close using "$ObPath/Table-Expt2014-`yX'-$spec", $OR2_nodec dec(2) append addstat(Mean dv if not close poll=1, zz) 
areg vote100 t_close_vscontrol t_notclose_vscontrol $FullCont_V2014, absorb(strata) cluster(hhid_unique)
	capture drop zz zz1
	egen zz1 = mean(vote100) if e(sample)==1 & mi(t_close)
	egen zz = max(zz1)	
	test t_close_vscontrol=t_notclose_vscontrol
	outreg2 t_close_vscontrol t_notclose_vscontrol using "$ObPath/Table-Expt2014-`yX'-$spec", $OR2_nodec dec(2) append addstat(Mean dv if control=1,zz,F(Close_vs_NotClose),r(p))
areg vote100 t_close t_fewvoters $FullCont_V2014, absorb(strata) cluster(hhid_unique)
	capture drop zz zz1
	egen zz1 = mean(vote100) if e(sample)==1 & t_close==0
	egen zz = max(zz1)	
	outreg2 t_close t_fewvoters using "$ObPath/Table-Expt2014-`yX'-$spec", $OR2_nodec dec(2) append	addstat(Mean dv if not close poll=1, zz)	
areg vote100 t_closeXt_fewvoters t_closeXt_manyvoters t_notcloseXt_fewvoters $FullCont_V2014, absorb(strata) cluster(hhid_unique)	
	capture drop zz zz1
	egen zz1 = mean(vote100) if e(sample)==1 & t_close==0
	egen zz = max(zz1)	
	outreg2 t_closeXt_fewvoters t_closeXt_manyvoters t_notcloseXt_fewvoters using "$ObPath/Table-Expt2014-`yX'-$spec", $OR2_nodec dec(2) append	addstat(Mean dv if not close poll=1, zz)	
}
	
